% LATEX DOCUMENT CLASS FOR 'INTERNATIONAL CONFERENCE ON APPLIED INFORMATICS'

\LoadClass[twoside]{article}
\RequirePackage[paperwidth=170mm,paperheight=240mm,
                width=126mm,height=189mm,headsep=5mm,
                top=28mm,outer=17mm,dvips]{geometry}
\RequirePackage[OT2,T1]{fontenc}
\RequirePackage{ntheorem}
\RequirePackage{fancyhdr}
\RequirePackage{graphicx}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{ifthen}
\RequirePackage{indentfirst}
\RequirePackage{titlesec}

% LastPageAction____________________________________________________
\def\LastPageAction{\newpage
\ifthenelse{\isodd{\thepage}}{\centerline{}\thispagestyle{empty}\newpage\centerline{}\thispagestyle{empty}}
{\centerline{}\thispagestyle{empty}}}

% OVERFULL _________________________________________________________
\overfullrule10pt

% ICAIvolume ________________________________________________________
\newenvironment{ICAIvolume}[1][others]{%
\input{#1/def}
\include{#1/front}
\newcommand*\l@papertitle{\@dottedtocline{0}{0em}{2.3em}}
\setcounter{tocdepth}{0}
\newpage\thispagestyle{empty}\tableofcontents}%
{\LastPageAction}

% PAGE BREAKS IN MATH MODE __________________________________________
\allowdisplaybreaks

% HEADLINES _________________________________________________________
\pagestyle{fancy}
\fancyhead[RO]{\thepage}
\fancyhead[LE]{\thepage}
\fancyfoot{}
\renewcommand{\ps@myheadings}{
\def\@oddfoot{\hfil\rm\thepage\hfil}
\def\@oddhead{\hfil{\em\firstlinE}\hfil}}

% NEW INCLUDE ________________________________________________________
\def\@include#1 {\authorinheadline{}\authorincontents{}\author{}\titleinheadline{\titlE}
    \titleincontents{\titlE}\title{}\institute{}\address{}\thanks{}\def\filenamE{#1}
    \clearpage
    \if@filesw \immediate\write\@mainaux{\string\@input{#1.aux}}\fi
    \@tempswatrue
    \if@partsw \@tempswafalse\edef\@tempb{#1}
       \@for\@tempa:=\@partlist\do{\ifx\@tempa\@tempb\@tempswatrue\fi}
    \fi
    \if@tempswa
       \if@filesw \let\@auxout=\@partaux
           \immediate\openout\@partaux #1.aux
           \immediate\write\@partaux{\relax}
       \fi
       \def\@bblfile{#1.bbl}\@input{#1.tex}
       \let\@bblfile\@mainbblfile\clearpage
       \@writeckpt{#1}
       \if@filesw
          \immediate\closeout\@partaux
       \fi
       \let\@auxout=\@mainaux\else\@nameuse{cp@#1}
   \fi}

% NEW DEFINITIONS ___________________________________________________
\def\firstlinE{8\/$^{th}$ International Conference on Applied Informatics}
\def\secondlinE{Eger, Hungary, January 27--30, 2010.}
\def\filenamE{}
\def\QEDsign{\hfill$\Box$}
\def\SizeOfReferences{\small}
\def\authorinheadline#1{\def\authorinheadlinE{#1}}\def\authorinheadlinE{}
\def\authorincontents#1{\def\authorincontentS{#1}}\def\authorincontentS{}
\def\author#1{\def\authoR{#1}}\def\authoR{}
\def\titleinheadline#1{\def\titleinheadlinE{#1}}\def\titleinheadlinE{}
\def\titleincontents#1{\def\titleincontentS{#1}}\def\titleincontentS{\titlE}
\def\thanks#1{\def\thankS{#1}}\def\thankS{}
\def\title#1{\def\titlE{#1}}\def\titlE{}
\def\institute#1{\def\institutE{#1}}\def\institutE{}
\def\address#1{\def\addresS{#1}}\def\addresS{}
\def\inst#1{\ifcase#1\or$^{a}$\or$^{b}$\or$^{c}$\or$^{d}$\or$^{e}$\or$^{f}$\or$^{g}$\or$^{h}$\or$^{i}$\or$^{j}$\fi}
\def\AND{\\[1.5mm] }
\def\starfootnote#1{%
\renewcommand{\thefootnote}{\hskip-2mm$\ast$}
\footnote{#1}
\renewcommand{\thefootnote}{\arabic{footnote}}
\addtocounter{footnote}{-1}}
\def\Thanks{\ifthenelse{\equal{\thankS}{}}{}{\starfootnote{\thankS}}}

\def\keywords{\\[1.5mm]\emph{Keywords:} }
\def\AMSclassificationnumber{\\[1.5mm]\emph{MSC:} }

\renewcommand{\theequation}{\thesection.\arabic{equation}}

\def\leq{\leqslant}
\def\geq{\geqslant}

% NEW CROSS REFERENCES ______________________________________________
\def\labelX#1{\label{\filenamE:#1}}
\def\refX#1{\ref{\filenamE:#1}}
\def\pagerefX#1{\pageref{\filenamE:#1}}
\def\eqrefX#1{\eqref{\filenamE:#1}}
\def\bibitemX#1{\bibitem{\filenamE:#1}}
\def\citeX#1{\cite{\filenamE:#1}}
\def\citeXX[#1]#2{\cite[#1]{\filenamE:#2}}

% NEW INCLUDEGRAPHICS ______________________________________________
\def\includegraphicsX[#1]#2{\includegraphics[#1]{\filenamE/#2}}

% SECTIONS _________________________________________________________
\titleformat{\section}{\Large\bfseries}{\setcounter{equation}{0}\thesection.}{.44em}{}
\titleformat{\subsection}{\large\bfseries}{\thesubsection.}{.44em}{}
\titleformat{\subsubsection}{\bfseries}{\thesubsubsection.}{.44em}{}

% NEW THEOREMS _____________________________________________________
\newtheoremstyle{icai}%
{\item[\hskip\labelsep\theorem@headerfont ##1\ ##2.]}%
{\item[\hskip\labelsep\theorem@headerfont ##1\ ##2\ \textnormal{(##3).}]}

\newtheoremstyle{withoutnumber}%
{\item[\hskip\labelsep\theorem@headerfont ##1.]}%
{\item[\hskip\labelsep\theorem@headerfont ##3.]}

\theoremstyle{icai}
\theorembodyfont{\it}\newtheorem{theorem}{Theorem}[section]
\theorembodyfont{\rm}\newtheorem{definition}[theorem]{Definition}
\theorembodyfont{\it}\newtheorem{lemma}[theorem]{Lemma}
\theorembodyfont{\it}\newtheorem{corollary}[theorem]{Corollary}
\theorembodyfont{\rm}\newtheorem{remark}[theorem]{Remark}
\theorembodyfont{\rm}\newtheorem{example}[theorem]{Example}
\theoremstyle{withoutnumber}
\theorembodyfont{\rm}\newtheorem{prooF}{Proof}

\newenvironment{proof}{\begin{prooF}}{\QEDsign\end{prooF}}

% NEW THEOREMS BY USERS ____________________________________________
\def\privatetheorem#1#2#3{%
\theoremstyle{icai}%
\theorembodyfont{#3}\newtheorem{#1}[theorem]{#2}}

% ICAIPAPER _________________________________________________________
\newenvironment{ICAIpaper}{
\ifthenelse{\isodd{\thepage}}{}{\centerline{}\thispagestyle{empty}\newpage}
\addcontentsline{toc}{papertitle}{\textsc{\authorincontentS}, \titleincontentS}
\setcounter{section}{0} \setcounter{subsection}{0}
\setcounter{subsubsection}{0}
\setcounter{equation}{0}\setcounter{figure}{0}
\setcounter{footnote}{0}\setcounter{table}{0}
\fancyhead[LO]{\textit{\small\titleinheadlinE}}
\fancyhead[RE]{\textit{\small\authorinheadlinE}}
\thispagestyle{myheadings}
\begin{center}
\vspace*{-8.5mm}
{\em\secondlinE}\vskip15mm
{\LARGE\bf\titlE\Thanks}\vskip8mm
{\large\bf\authoR}\vskip5mm
{\small\rm\institutE}\vskip8mm
\end{center}}
{\par\bigskip\goodbreak\noindent{\small\addresS}}


\endinput
